@@ -6,6 +6,7 @@ docker_image="$1"
 rpmbuild="$2"
 
 PLUGIN_NAME=$(awk '/^project\(/{print gensub(/project\(([^ ()]*).*/, "\\1", 1, $0)}' CMakeLists.txt)
+PLUGIN_NAME_FEDORA="$(sed -e 's/^obs-/obs-studio-plugin-/' <<< "$PLUGIN_NAME")"
 eval $(git describe --tag --always --long | awk '
 BEGIN {
 	VERSION="unknown";
@@ -32,16 +33,17 @@ test -x /usr/sbin/selinuxenabled && /usr/sbin/selinuxenabled && chcon -Rt contai
 # Prepare files
 sed \
 	-e "s/@PLUGIN_NAME@/$PLUGIN_NAME/g" \
+	-e "s/@PLUGIN_NAME_FEDORA@/$PLUGIN_NAME_FEDORA/g" \
 	-e "s/@VERSION@/$VERSION/g" \
 	-e "s/@RELEASE@/$RELEASE/g" \
 	< ci/plugin.spec \
-	> $rpmbuild/SPECS/$PLUGIN_NAME.spec
+	> $rpmbuild/SPECS/$PLUGIN_NAME_FEDORA.spec
 
-git archive --format=tar --prefix=$PLUGIN_NAME-$VERSION/ HEAD | bzip2 > $rpmbuild/SOURCES/$PLUGIN_NAME-$VERSION.tar.bz2
+git archive --format=tar --prefix=$PLUGIN_NAME_FEDORA-$VERSION/ HEAD | bzip2 > $rpmbuild/SOURCES/$PLUGIN_NAME_FEDORA-$VERSION.tar.bz2
 
 docker run -v $rpmbuild:/home/rpm/rpmbuild $docker_image bash -c "
-sudo dnf builddep -y ~/rpmbuild/SPECS/$PLUGIN_NAME.spec &&
+sudo dnf builddep -y ~/rpmbuild/SPECS/$PLUGIN_NAME_FEDORA.spec &&
 sudo chown 0.0 ~/rpmbuild/SOURCES/* &&
 sudo chown 0.0 ~/rpmbuild/SPECS/* &&
-rpmbuild -ba ~/rpmbuild/SPECS/$PLUGIN_NAME.spec
+rpmbuild -ba ~/rpmbuild/SPECS/$PLUGIN_NAME_FEDORA.spec
 "
